@@ -1,3 +1,5 @@
+import importlib
+
 import cv2
 from cv2 import face
 import matplotlib.pyplot as plt
@@ -5,7 +7,8 @@ import numpy as np
 
 import blurredface_sts_test
 import os
-import pkg_resources
+
+import importlib.resources as pkgresources
 
 
 def prinfPath():
@@ -45,11 +48,12 @@ def faceRecognizer(filepath):
     # cv2.namedWindow('recognizer')
     # OpenCV人脸识别分类器
     classifier_default = cv2.CascadeClassifier(
-        # "haarcascades/haarcascade_frontalface_default.xml"
+        #"haarcascades/haarcascade_frontalface_default.xml"
         # "haarcascade_frontalface_default.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_default
         # parent+"\haarcascades\haarcascade_frontalface_default.xml"
-        "haarcascade_frontalface_default.xml"
+        #"haarcascade_frontalface_default.xml"
+        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_default.xml")
 
     )
     classifier_alt_tree = cv2.CascadeClassifier(
@@ -57,28 +61,32 @@ def faceRecognizer(filepath):
         # "haarcascade_frontalface_alt_tree.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt_tree
         # parent + "\haarcascades\haarcascade_frontalface_alt_tree.xml"
-        "haarcascade_frontalface_alt_tree.xml"
+        #"haarcascade_frontalface_alt_tree.xml"
+        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt_tree.xml")
     )
     classifier_alt2 = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt2.xml"
         # "haarcascade_frontalface_alt2.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt2
         # parent+"\haarcascades\haarcascade_frontalface_alt2.xml"
-        "haarcascade_frontalface_alt2.xml"
+        #"haarcascade_frontalface_alt2.xml"
+        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt2.xml")
     )
     classifier_alt = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt.xml"
         # "haarcascade_frontalface_alt.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt
         # parent + "\haarcascades\haarcascade_frontalface_alt.xml"
-        "haarcascade_frontalface_alt.xml"
+        #"haarcascade_frontalface_alt.xml"
+        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt.xml")
     )
     classifier_ce = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_profileface.xml"
         # "haarcascade_profileface.xml"
         # blurredface_sts_test.haarcascade.haarcascade_profileface
         # parent+"\haarcascades\haarcascade_profileface.xml"
-        "haarcascade_profileface.xml"
+        #"haarcascade_profileface.xml"
+        pkgresources.path(blurredface_sts_test, "haarcascade_profileface.xml")
     )
     color = (0, 0, 255)  # 定义绘制颜色
     # 调用识别人脸
